+++
title = "Deeply nested Org TODO headings – Default heading level"
tags = ["todo", "nested"]
draft = false
+++

`ox-hugo` Issue #[250](https://github.com/kaushalmodi/ox-hugo/issues/250)


## <span class="org-todo todo TODO">TODO</span> Level 1 {#level-1}


### <span class="org-todo todo TODO">TODO</span> Level 2 {#level-2}


#### <span class="org-todo todo TODO">TODO</span> Level 3 {#level-3}


##### <span class="org-todo todo TODO">TODO</span> Level 4 {#level-4}

<!--list-separator-->

- <span class="org-todo todo TODO">TODO</span>  Level 5

    <!--list-separator-->

    - <span class="org-todo todo TODO">TODO</span>  Level 6

        <!--list-separator-->

        - <span class="org-todo todo TODO">TODO</span>  Level 7
